@@ -14,12 +14,13 @@ from .colors import COLORS, RESET
 
 class Checker:
     def __init__(self, title: str, banner: str = "", proxy: bool = False, color: str = "red",
-                 mode: str = "log") -> None:
+                 mode: str = "log", capture: bool = False) -> None:
         self.banner = banner
         self.proxy = proxy
         self.color = COLORS[color]
         self.mode = mode
         self.title = title
+        self.capture = capture
         self.cpm = 0
         self.cui_thread_status = True  # When this is false, the cui thread will stop
         self.threads = []
@@ -140,17 +141,23 @@ class Checker:
         while True:
             try:
                 combo = q.get()
-                email, password = combo.split(":")
+                try:
+                    email, password = combo.split(":")
+                except ValueError:
+                    pass
             except queue.Empty:
                 return
 
             result = check(email, password, proxy)
-            match result:
+            match result[0]:
                 case "good":
                     self.data["hits"] += 1
                     self.data["checked"] += 1
                     if self.mode == "log":
-                        print(f"[{COLORS['green']}+{RESET}] {COLORS['green']}-{RESET} {combo}")
+                        if self.capture:
+                            print(f"[{COLORS['green']}+{RESET}] {COLORS['green']}-{RESET} {combo} | {result[1]}")
+                        else:
+                            print(f"[{COLORS['green']}+{RESET}] {COLORS['green']}-{RESET} {combo}")
                 case "bad":
                     self.data["bad"] += 1
                     self.data["checked"] += 1
